Uses of Class org.openqa.selenium.server.CommandQueue (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Class
org.openqa.selenium.server.CommandQueue

Packages that use CommandQueue
org.openqa.selenium.server | Provides the core Selenium Server classes.
org.openqa.selenium.server.browserlaunchers | Provides classes to launch and kill browsers.

Uses of CommandQueue in org.openqa.selenium.server

Methods in org.openqa.selenium.server that return CommandQueue
`CommandQueue` | `FrameGroupCommandQueueSet.getCommandQueue()`
`CommandQueue` | `FrameGroupCommandQueueSet.getCommandQueue(java.lang.String uniqueId)`

Uses of CommandQueue in org.openqa.selenium.server.browserlaunchers

Methods in org.openqa.selenium.server.browserlaunchers with parameters of type CommandQueue
`void` | `CommandQueueAware.setCommandQueue(CommandQueue queue)`

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.